Setup file
==========

TODO

* Command line arguments can be set in setup file
* `render_path()`, expanded variables and user directories


Sections
--------

* setup
* vcs
* renderer
* action
* misc
* *plugin_id*

Options
-------

* Plusieurs sections
  * `enable_plugins`, `disable_plugins`, default, required plugins, plugin dependency, etc.
* `setup`
  * `source`
  * `vcs`
  * `cachedir`
  * `libdirs`
* `renderer.htmlplus` TODO Move this to renderer.htmlplus section plugin page
  * `destfile`
  * `destdir`
  * `href_prefix`
  * `templatedirs`
  * `template`
  * `staticdir`
  * `title`

